@@ -5,10 +5,9 @@
  *
  * Author:  jacob berkman  <jacob@bug-buddy.org>
  *
- * This program is free software; you can redistribute it and/or modify
- * it under the terms of the GNU General Public License as published by
- * the Free Software Foundation; either version 2 of the License, or
- * (at your option) any later version.
+ * This program is free software; you can redistribute it and/or
+ * modify it under the terms of version 2 of the GNU General Public
+ * License as published by the Free Software Foundation.
  *
  * This program is distributed in the hope that it will be useful,
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
@@ -23,13 +22,16 @@
 #ifndef __BUG_BUDDY_H__
 #define __BUG_BUDDY_H__
 
+#include "bugzilla.h"
+
 #include <glade/glade.h>
-#include <libgnomeui/gnome-canvas.h>
+#include <libgnomecanvas/gnome-canvas.h>
 #include <gdk-pixbuf/gdk-pixbuf.h>
+#include <gtk/gtkliststore.h>
+#include <gtk/gtktreeviewcolumn.h>
+#include <libgnomevfs/gnome-vfs-async-ops.h>
 
 #include <sys/types.h>
-#include "distro.h"
-#include "bugzilla.h"
 
 typedef enum {
 	CRASH_DIALOG,
@@ -51,18 +53,16 @@ typedef enum {
 typedef enum {
 	STATE_INTRO,
 	STATE_GDB,
-	STATE_DESC,
-	STATE_UPDATE,
 	STATE_PRODUCT,
 	STATE_COMPONENT,
+	STATE_MOSTFREQ,
+	STATE_DESC,
 	STATE_SYSTEM,
 	STATE_EMAIL,
 	STATE_FINISHED,
 	STATE_LAST
 } BuddyState;
 
-#define GET_WIDGET(name) (glade_xml_get_widget (druid_data.xml, (name)))
-
 typedef struct {
 	/* contact page */
 	gchar *name;
@@ -103,7 +103,9 @@ typedef struct {
 
 	gboolean already_run;
 
+#if 0
 	Distribution      *distro;
+#endif
 	char              *bts_file;
 
 	CrashType  crash_type;
@@ -130,6 +132,8 @@ typedef struct {
 #endif
 	GSList       *packages;
 
+	GSList       *bugs;
+
 	/* Bugzilla BTS stuff */
 	BugzillaProduct   *product;
 	BugzillaComponent *component;
@@ -140,6 +144,11 @@ typedef struct {
 
 	GnomeVFSAsyncHandle *vfshandle;
 	gboolean need_to_download;
+
+	GtkTreeViewColumn *uri_column;
+	gboolean           showing_hand;
+
+	const char *gnome_version;
 } DruidData;
 
 extern DruidData druid_data;
@@ -162,4 +171,13 @@ void append_packages (void);
 void load_config (void);
 void save_config (void);
 
+#define GET_WIDGET(name) (glade_xml_get_widget (druid_data.xml, (name)))
+
+/* GTK's text widgets have sucky apis */
+char *buddy_get_text_widget (GtkWidget *w);
+#define buddy_get_text(w) (buddy_get_text_widget (GET_WIDGET (w)))
+
+void  buddy_set_text_widget (GtkWidget *w, const char *s);
+#define buddy_set_text(w, s) (buddy_set_text_widget (GET_WIDGET (w), s))
+
 #endif /* __bug_buddy_h__ */
