@@ -132,7 +132,7 @@ stop_gdb (void)
 	gtk_widget_set_sensitive (GTK_WIDGET (GET_WIDGET ("gdb-go")), TRUE);
 
 	if (GTK_TOGGLE_BUTTON (GET_WIDGET ("gdb-continue-toggle"))->active)
-		druid_set_state (STATE_DESC);
+		druid_set_state (STATE_PRODUCT);
 	return;
 }
 
@@ -153,11 +153,12 @@ get_trace_from_core (const gchar *core_file)
 	if (!f) {
 		GtkWidget *d;
 		d = gtk_message_dialog_new (GTK_WINDOW (GET_WIDGET ("druid-window")),
-					    GTK_DIALOG_NO_SEPARATOR,
+					    0,
 					    GTK_MESSAGE_ERROR,
 					    GTK_BUTTONS_OK,
 					    _("Unable to process core file with gdb:\n"
 					      "'%s'"), core_file);
+		gtk_dialog_set_default_response (GTK_DIALOG (d), GTK_RESPONSE_OK);
 		gtk_dialog_run (GTK_DIALOG (d));
 		gtk_widget_destroy (d);
 		return;
@@ -183,11 +184,12 @@ get_trace_from_core (const gchar *core_file)
 	if (!binary) {
 		GtkWidget *d;
 		d = gtk_message_dialog_new (GTK_WINDOW (GET_WIDGET ("druid-window")),
-					    GTK_DIALOG_NO_SEPARATOR,
+					    0,
 					    GTK_MESSAGE_ERROR,
 					    GTK_BUTTONS_OK,
 					    _("GDB was unable to determine which binary created\n"
 					      "'%s'"), core_file);
+		gtk_dialog_set_default_response (GTK_DIALOG (d), GTK_RESPONSE_OK);
 		gtk_dialog_run (GTK_DIALOG (d));
 		gtk_widget_destroy (d);
 		return;
@@ -254,17 +256,19 @@ get_trace_from_pair (const gchar *app, const gchar *extra)
 			 "--quiet",
 			 "--command=" BUDDY_DATADIR "/gdb-cmd",
 			 NULL, NULL, NULL };
-	args[0] = gnome_is_program_in_path ("gdb");
+	args[0] = g_find_program_in_path ("gdb");
 	args[5] = (char *)extra;
 
 	if (!args[0]) {
 		d = gtk_message_dialog_new (GTK_WINDOW (GET_WIDGET ("druid-window")),
-					    GTK_DIALOG_NO_SEPARATOR,
+					    0,
 					    GTK_MESSAGE_ERROR,
 					    GTK_BUTTONS_OK,
 					    _("GDB could not be found on your system.\n"
 					      "Debugging information will not be obtained."));
 		d(g_message ("Path: %s", getenv ("PATH")));
+		gtk_dialog_set_default_response (GTK_DIALOG (d),
+						 GTK_RESPONSE_OK);
 		gtk_dialog_run (GTK_DIALOG (d));
 		gtk_widget_destroy (d);
 		return;
@@ -278,7 +282,7 @@ get_trace_from_pair (const gchar *app, const gchar *extra)
 	if (g_file_test (app, G_FILE_TEST_IS_REGULAR | G_FILE_TEST_IS_SYMLINK))
 		app2 = g_strdup (app);
 	else
-		app2 = gnome_is_program_in_path (app);
+		app2 = g_find_program_in_path (app);
 
 	if (!app2) {
 		g_free (args[0]);
@@ -291,12 +295,14 @@ get_trace_from_pair (const gchar *app, const gchar *extra)
 	
 	if (!g_file_test (BUDDY_DATADIR "/gdb-cmd", G_FILE_TEST_EXISTS)) {
 		d = gtk_message_dialog_new (GTK_WINDOW (GET_WIDGET ("druid-window")),
-					    GTK_DIALOG_NO_SEPARATOR,
+					    0,
 					    GTK_MESSAGE_ERROR,
 					    GTK_BUTTONS_OK,
 					    _("Could not find the gdb-cmd file.\n"
 					      "Please try reinstalling Bug Buddy."));
 		gtk_dialog_run (GTK_DIALOG (d));
+		gtk_dialog_set_default_response (GTK_DIALOG (d),
+						 GTK_RESPONSE_OK);
 		gtk_widget_destroy (d);
 		g_free (app2);
 		return;
@@ -309,11 +315,13 @@ get_trace_from_pair (const gchar *app, const gchar *extra)
 				       &druid_data.fd, 
 				       NULL, NULL)) {
 		d = gtk_message_dialog_new (GTK_WINDOW (GTK_WIDGET ("druid-window")),
-					    GTK_DIALOG_NO_SEPARATOR,
+					    0,
 					    GTK_MESSAGE_ERROR,
 					    GTK_BUTTONS_OK,
 					    _("There was an error running gdb."));
 		gtk_dialog_run (GTK_DIALOG (d));
+		gtk_dialog_set_default_response (GTK_DIALOG (d),
+						 GTK_RESPONSE_OK);
 		gtk_widget_destroy (d);
 		g_free (app2);
 		return;
